/***************************************************************************
*
*	File name : cmu_drv.c
*	Function  : CMU Driver
*	Revision  :
*		10/03/2007	Nariai		First revision
*
****************************************************************************/


// Include Files
#include	"reg_801.h"
#include	"system.h"
#include	"cmu_api.h"


// Prototype
void CmuInit(T_CMU_CFG *pConfig);


/***************************************************************************
	CmuInit

	description	: Initialize CMU
	argument	: pConfig	: pointer of CMU configuration info.
	return: 	: None

***************************************************************************/
void CmuInit(T_CMU_CFG *pConfig){

	// Disable write protect
	CmuWrProtectDisable();

	// Setting noise filter
	if(pConfig->osc3Nf == CMU_NF_ENABLE){
		CmuOsc3NfEnable();
	} else {
		CmuOsc3NfDisable();
	}

	if(pConfig->inPortNf == CMU_NF_ENABLE){
		CmuInPortNfEnable();
	} else {
		CmuInPortNfDisable();
	}

	if(pConfig->dsioNf == CMU_NF_ENABLE){
		CmuDsioInNfEnable();
	} else {
		CmuDsioInNfDisable();
	}

	// Setting OSC3 clock divider
	CmuSetOsc3ClkDiv(pConfig->osc3ClockDiv);

	// Setting LCDC clock divider
	CmuSetLcdcClkDiv(pConfig->lcdcClockDiv);

	// Setting "CMU_CLK" select
	CmuSetCmuClkSel(pConfig->cmuClockSel);

	// Setting gated clock
	CmuSetGatedClk0(pConfig->gatedClk0.reg);
	CmuSetGatedClk1(pConfig->gatedClk1.reg);
	CmuSetGatedClk2(pConfig->gatedClk2.reg);

	// Setting USB wait
	CmuSetUsbWait(pConfig->usbWait);

	// Setting USB snooze
	if(pConfig->usbSnooze == CMU_USB_SNOOZE_DISABLE){
		CmuUsbSnoozeDisable();
	} else {
		CmuUsbSnoozeEnable();
	}

	return;

}

