/***************************************************************************
*
*	File name : main.c
*	Function  : Main function
*	Revision  :
*		07/31/2007	Nariai		First revision
*
****************************************************************************/

// Include File
#include	<string.h>
#include	<stdio.h>
#include	<stdlib.h>
#include	<libstdio.h>
#include	"reg_801.h"
#include	"t8_api.h"
#include	"itc_api.h"

// Define
#define	CpuIntEnable()		asm("ei")
#define	CpuIntDisable()		asm("di")


// Prototype
int main(void);
static void ExecuteT8Ch0(void);
static void ExecuteT8Ch1(void);
static void ExecuteT8Ch2(void);
static void ExecuteT8Ch3(void);
void t8ch0_int(void);
void t8ch1_int(void);
void t8ch2_int(void);
void t8ch3_int(void);

// global
unsigned short	g_TimCnt0;
unsigned short	g_TimCnt1;
unsigned short	g_TimCnt2;
unsigned short	g_TimCnt3;


/***************************************************************************
	main

	description	: main function
	argument	: None
	return: 	: None
***************************************************************************/
int main(void){
	
	T_T8_CFG				T8Config;
	unsigned char			event	= 0;
	unsigned short			counter	= 0;
	
	// CPU interrupt enable
	CpuIntEnable();
	
	// Init. ITC for T8
	ItcT8Ch0IntDisable();
	ItcClrT8Ch0Int();
	ItcSetT8Ch0IntLv(5);
	ItcT8Ch1IntDisable();
	ItcClrT8Ch1Int();
	ItcSetT8Ch1IntLv(5);
	ItcT8Ch2IntDisable();
	ItcClrT8Ch2Int();
	ItcSetT8Ch2IntLv(5);
	ItcT8Ch3IntDisable();
	ItcClrT8Ch3Int();
	ItcSetT8Ch3IntLv(5);
	ItcFuncEnable();
	
	// Init. T8
//	T8Config.ReloadData	= 0x0C;
//	T8Config.PclkDiv	= T8_PCLK_4096;
	T8Config.ReloadData	= 187;
	T8Config.PclkDiv	= T8_PCLK_256;
	T8Config.intFunc	= t8ch0_int;
	T8Init(T8_CH_0, &T8Config);
	T8Config.intFunc	= t8ch1_int;
	T8Init(T8_CH_1, &T8Config);
	T8Config.intFunc	= t8ch2_int;
	T8Init(T8_CH_2, &T8Config);
	T8Config.intFunc	= t8ch3_int;
	T8Init(T8_CH_3, &T8Config);
	
	// Execute T8
	ExecuteT8Ch0();
	ExecuteT8Ch1();
	ExecuteT8Ch2();
	ExecuteT8Ch3();
	
	return 0;

}


/***************************************************************************
	ExecuteT8Ch0

	description	: Execute T8(Ch.0)
	argument	: None
	return: 	: None
***************************************************************************/
void ExecuteT8Ch0(void){
	
	unsigned short			counter = 0;
	
	// Init. global
	g_TimCnt0			= 0;
	
	// Start CLG
	T8Start(T8_CH_0);
	
	// Enable T8(Ch.0)interrupt
	ItcT8Ch0IntEnable();
	
	printf("> T8(Ch.0) Start\n");
	
	while(1){
		
		if(g_TimCnt0 == 1000){
			g_TimCnt0	= 0;
			
			counter++;
			printf("> T8(Ch.0) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	// Stop timer
	T8Stop(T8_CH_0);
	
	printf("> T8(Ch.0) End\n\n");
	
	return;
	
}


/***************************************************************************
	ExecuteT8Ch1

	description	: Execute T8(Ch.1)
	argument	: None
	return: 	: None
***************************************************************************/
void ExecuteT8Ch1(void){
	
	unsigned short			counter = 0;
	
	// Init. global
	g_TimCnt1			= 0;
	
	// Start CLG
	T8Start(T8_CH_1);
	
	// Enable T8(Ch.1)interrupt
	ItcT8Ch1IntEnable();
	
	printf("> T8(Ch.1) Start\n");
	
	while(1){
		
		if(g_TimCnt1 == 1000){
			g_TimCnt1	= 0;
			
			counter++;
			printf("> T8(Ch.1) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	// Stop timer
	T8Stop(T8_CH_1);
	
	printf("> T8(Ch.1) End\n\n");
	
	return;
	
}


/***************************************************************************
	ExecuteT8Ch2

	description	: Execute T8(Ch.2)
	argument	: None
	return: 	: None
***************************************************************************/
void ExecuteT8Ch2(void){
	
	unsigned short			counter = 0;
	
	// Init. global
	g_TimCnt2			= 0;
	
	// Start CLG
	T8Start(T8_CH_2);
	
	// Enable T8(Ch.2)interrupt
	ItcT8Ch2IntEnable();
	
	printf("> T8(Ch.2) Start\n");
	
	while(1){
		
		if(g_TimCnt2 == 1000){
			g_TimCnt2	= 0;
			
			counter++;
			printf("> T8(Ch.2) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	// Stop timer
	T8Stop(T8_CH_2);
	
	printf("> T8(Ch.2) End\n\n");
	
	return;
	
}


/***************************************************************************
	ExecuteT8Ch3

	description	: Execute T8(Ch.3)
	argument	: None
	return: 	: None
***************************************************************************/
void ExecuteT8Ch3(void){
	
	unsigned short			counter = 0;
	
	// Init. global
	g_TimCnt3			= 0;
	
	// Start CLG
	T8Start(T8_CH_3);
	
	// Enable T8(Ch.3)interrupt
	ItcT8Ch3IntEnable();
	
	printf("> T8(Ch.3) Start\n");
	
	while(1){
		
		if(g_TimCnt3 == 1000){
			g_TimCnt3	= 0;
			
			counter++;
			printf("> T8(Ch.3) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	// Stop timer
	T8Stop(T8_CH_3);
	
	printf("> T8(Ch.3) End\n");
	
	return;
	
}

/***************************************************************************
	t8ch0_int/t8ch1_int/t8ch2_int/t8ch3_int

	description	: T8 ch0~3 interrupt handler 
	argument	: None
	return: 	: None
***************************************************************************/
void t8ch0_int(void)
{
	g_TimCnt0++;
	
}
void t8ch1_int(void)
{
	g_TimCnt1++;
	
}
void t8ch2_int(void)
{
	g_TimCnt2++;
	
}
void t8ch3_int(void)
{
	g_TimCnt3++;
	
}
