/***************************************************************************
*
*	File name : sramc_drv.c
*	Function  : SRAMC Driver
*	Revision  :
*		10/03/2007	Nariai		First revision
*
****************************************************************************/

// Include Files
#include	"reg_801.h"
#include	"sramc_api.h"


// Prototype
void SramcInit(T_SRAMC_CFG *pConfig);

/***************************************************************************
	SramcInit

	description	: Initialize SRAMC
	argument	: pConfig	: pointer of SRAMC configuration info.
	return: 	: None
	
***************************************************************************/
void SramcInit(T_SRAMC_CFG *pConfig){
	
	// Set external memory wait
	SramcSetExtMemWaitCE0(pConfig->ce0Wait);
	SramcSetExtMemWaitCE1(pConfig->ce1Wait);
	SramcSetExtMemWaitCE2(pConfig->ce2Wait);
	SramcSetExtMemWaitCE3(pConfig->ce3Wait);
	
	// Set CE0 device size
	if(pConfig->ce0DevSize == SRAMC_DEV_SIZE_8BIT){
		// 8bit
		SramcSetExtMemSizeCE0_8Bit();
	} else {
		// 16bit
		SramcSetExtMemSizeCE0_16Bit();
	}
	
	// Set CE1 device size
	if(pConfig->ce1DevSize == SRAMC_DEV_SIZE_8BIT){
		// 8bit
		SramcSetExtMemSizeCE1_8Bit();
	} else {
		// 16bit
		SramcSetExtMemSizeCE1_16Bit();
	}
	
	// Set CE2 device size
	if(pConfig->ce2DevSize == SRAMC_DEV_SIZE_8BIT){
		// 8bit
		SramcSetExtMemSizeCE2_8Bit();
	} else {
		// 16bit
		SramcSetExtMemSizeCE2_16Bit();
	}
	
	// Set CE3 device size
	if(pConfig->ce3DevSize == SRAMC_DEV_SIZE_8BIT){
		// 8bit
		SramcSetExtMemSizeCE3_8Bit();
	} else {
		// 16bit
		SramcSetExtMemSizeCE3_16Bit();
	}
	
	// Set CE0 memory type
	if(pConfig->ce0MemType == SRAMC_MEM_TYPE_A0){
		// A0
		SramcSetExtMemTypeCE0_A0();
	} else {
		// BSL
		SramcSetExtMemTypeCE0_BSL();
	}
	
	// Set CE1 memory type
	if(pConfig->ce1MemType == SRAMC_MEM_TYPE_A0){
		// A0
		SramcSetExtMemTypeCE1_A0();
	} else {
		// BSL
		SramcSetExtMemTypeCE1_BSL();
	}
	
	// Set CE2 memory type
	if(pConfig->ce2MemType == SRAMC_MEM_TYPE_A0){
		// A0
		SramcSetExtMemTypeCE2_A0();
	} else {
		// BSL
		SramcSetExtMemTypeCE2_BSL();
	}
	
	// Set CE3 memory type
	if(pConfig->ce3MemType == SRAMC_MEM_TYPE_A0){
		// A0
		SramcSetExtMemTypeCE3_A0();
	} else {
		// BSL
		SramcSetExtMemTypeCE3_BSL();
	}
	
	// Select EVRAM
	SramcSetEvramSel(pConfig->selEvram);
	
	// Set IRAM wait
	SramcSetIramWait(pConfig->iramWait);
	
	// Set MAC Mark wait
	SramcSetMacMarkWait(pConfig->macWait);
	
	// Set RTC wait
	SramcSetRtcWait(pConfig->rtcWait);
	
	return;
	
}

