/***************************************************************************
*
*	File name : t8_drv.c
*	Function  : T8 Driver
*	Revision  :
*		08/02/2007	Nariai		First revision
*		03/06/2008	Matsumoto	modify function T8ChxInit().
*
****************************************************************************/

// Include File
#include	"system.h"
#include	"reg_801.h"
#include	"t8_api.h"

// Prototype
void T8Init(unsigned char chNo, T_T8_CFG *pConfig);
void T8Start(unsigned char chNo);
void T8Stop(unsigned char chNo);
void T8Ch0IntProc(void);
void T8Ch1IntProc(void);
void T8Ch2IntProc(void);
void T8Ch3IntProc(void);

static void T8Ch0Init(T_T8_CFG *pConfig);
static void T8Ch1Init(T_T8_CFG *pConfig);
static void T8Ch2Init(T_T8_CFG *pConfig);
static void T8Ch3Init(T_T8_CFG *pConfig);
static void T8Ch0Start(void);
static void T8Ch1Start(void);
static void T8Ch2Start(void);
static void T8Ch3Start(void);
static void T8Ch0Stop(void);
static void T8Ch1Stop(void);
static void T8Ch2Stop(void);
static void T8Ch3Stop(void);
static void T8DummyIntProc(void);

static void	(*interruptFunctionCh0)(void);
static void	(*interruptFunctionCh1)(void);
static void	(*interruptFunctionCh2)(void);
static void	(*interruptFunctionCh3)(void);

/***************************************************************************
	T8Init

	description	: Init. T8
	argument	: None
	return: 	: None
***************************************************************************/
void T8Init(unsigned char chNo, T_T8_CFG *pConfig){



	switch(chNo) {
		case T8_CH_0:
			interruptFunctionCh0 = T8DummyIntProc;
			T8Ch0Init(pConfig);
			break;

		case T8_CH_1:
			interruptFunctionCh1 = T8DummyIntProc;
			T8Ch1Init(pConfig);
			break;

		case T8_CH_2:
			interruptFunctionCh2 = T8DummyIntProc;
			T8Ch2Init(pConfig);
			break;

		case T8_CH_3:
			interruptFunctionCh3 = T8DummyIntProc;
			T8Ch3Init(pConfig);
			break;

		default:
			break;

	}

	return;

}


/***************************************************************************
	T8Start

	description	: Start T8
	argument	: None
	return: 	: None
***************************************************************************/
void T8Start(unsigned char chNo){

	switch(chNo) {
		case T8_CH_0:
			T8Ch0Start();
			break;

		case T8_CH_1:
			T8Ch1Start();
			break;

		case T8_CH_2:
			T8Ch2Start();
			break;

		case T8_CH_3:
			T8Ch3Start();
			break;

		default:
			break;

	}

	return;

}


/***************************************************************************
	T8Stop

	description	: Stop T8
	argument	: None
	return: 	: None
***************************************************************************/
void T8Stop(unsigned char chNo){

	switch(chNo) {
		case T8_CH_0:
			T8Ch0Stop();
			break;

		case T8_CH_1:
			T8Ch1Stop();
			break;

		case T8_CH_2:
			T8Ch2Stop();
			break;

		case T8_CH_3:
			T8Ch3Stop();
			break;

		default:
			break;

	}

	return;

}

/***************************************************************************
	T8Ch0IntProc

	description	: Interrupt handler T8 ch.0
	argument	: None
	return: 	: None
***************************************************************************/
void T8Ch0IntProc(void){

	interruptFunctionCh0();

	return;
}


/***************************************************************************
	T8Ch1IntProc

	description	: Interrupt handler T8 ch.1
	argument	: None
	return: 	: None
***************************************************************************/
void T8Ch1IntProc(void){

	interruptFunctionCh1();

	return;
}


/***************************************************************************
	T8Ch2IntProc

	description	: Interrupt handler T8 ch.2
	argument	: None
	return: 	: None
***************************************************************************/
void T8Ch2IntProc(void){

	interruptFunctionCh2();

	return;
}


/***************************************************************************
	T8Ch3IntProc

	description	: Interrupt handler T8 ch.3
	argument	: None
	return: 	: None
***************************************************************************/
void T8Ch3IntProc(void){

	interruptFunctionCh3();

	return;
}

/* ----- static ----- */

/***************************************************************************
	T8Ch0Init

	description	: Init. T8 Ch.0
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch0Init(T_T8_CFG *pConfig){

	T8Ch0Stop();

	T8_CLK0		= T8_CLK0 & ~(T8_CLK0_P8TS);
	T8_CLK0		= T8_CLK0 | (pConfig->PclkDiv & T8_CLK0_P8TS);
	T8_RLD0		= pConfig->ReloadData;

	// set interrupt function
	if(pConfig->intFunc != NULL){
		interruptFunctionCh0 = pConfig->intFunc;
	}
	
	return;

}


/***************************************************************************
	T8Ch1Init

	description	: Init. T8 Ch.1
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch1Init(T_T8_CFG *pConfig){

	T8Ch1Stop();

	T8_CLK1		= T8_CLK1 & ~(T8_CLK1_P8TS);
	T8_CLK1		= T8_CLK1 | (pConfig->PclkDiv & T8_CLK1_P8TS);
	T8_RLD1		= pConfig->ReloadData;

	// set interrupt function
	if(pConfig->intFunc != NULL){
		interruptFunctionCh1 = pConfig->intFunc;
	}
	
	return;

}


/***************************************************************************
	T8Ch2Init

	description	: Init. T8 Ch.2
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch2Init(T_T8_CFG *pConfig){

	T8Ch2Stop();

	T8_CLK2		= T8_CLK2 & ~(T8_CLK2_P8TS);
	T8_CLK2		= T8_CLK2 | (pConfig->PclkDiv & T8_CLK2_P8TS);
	T8_RLD2		= pConfig->ReloadData;

	// set interrupt function
	if(pConfig->intFunc != NULL){
		interruptFunctionCh2 = pConfig->intFunc;
	}
	
	return;

}


/***************************************************************************
	T8Ch3Init

	description	: Init. T8 Ch.3
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch3Init(T_T8_CFG *pConfig){

	T8Ch3Stop();

	T8_CLK3		= T8_CLK3 & ~(T8_CLK3_P8TS);
	T8_CLK3		= T8_CLK3 | (pConfig->PclkDiv & T8_CLK3_P8TS);
	T8_RLD3		= pConfig->ReloadData;

	// set interrupt function
	if(pConfig->intFunc != NULL){
		interruptFunctionCh3 = pConfig->intFunc;
	}
	
	return;

}


/***************************************************************************
	T8Ch0Start

	description	: Start T8 Ch.0
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch0Start(void){

	T8_CLK0		= T8_CLK0 | T8_CLK0_P8TON;
	T8_CTL0		= T8_CTL0 | T8_CTL0_PSET;
	T8_CTL0		= T8_CTL0 | T8_CTL0_PTRUN;

	return;

}


/***************************************************************************
	T8Ch1Start

	description	: Start T8 Ch.1
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch1Start(void){

	T8_CLK1		= T8_CLK1 | T8_CLK1_P8TON;
	T8_CTL1		= T8_CTL1 | T8_CTL1_PSET;
	T8_CTL1		= T8_CTL1 | T8_CTL1_PTRUN;

	return;

}


/***************************************************************************
	T8Ch2Start

	description	: Start T8 Ch.2
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch2Start(void){

	T8_CLK2		= T8_CLK2 | T8_CLK2_P8TON;
	T8_CTL2		= T8_CTL2 | T8_CTL2_PSET;
	T8_CTL2		= T8_CTL2 | T8_CTL2_PTRUN;

	return;

}


/***************************************************************************
	T8Ch3Start

	description	: Start T8 Ch.3
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch3Start(void){

	T8_CLK3		= T8_CLK3 | T8_CLK3_P8TON;
	T8_CTL3		= T8_CTL3 | T8_CTL3_PSET;
	T8_CTL3		= T8_CTL3 | T8_CTL3_PTRUN;

	return;

}


/***************************************************************************
	T8Ch0Stop

	description	: Stop T8 Ch.0
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch0Stop(void){

	T8_CTL0		= T8_CTL0 & ~(T8_CTL0_PTRUN);
	T8_CLK0		= T8_CLK0 & ~(T8_CLK0_P8TON);

	return;

}


/***************************************************************************
	T8Ch1Stop

	description	: Stop T8 Ch.1
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch1Stop(void){

	T8_CTL1		= T8_CTL1 & ~(T8_CTL1_PTRUN);
	T8_CLK1		= T8_CLK1 & ~(T8_CLK1_P8TON);

	return;

}


/***************************************************************************
	T8Ch2Stop

	description	: Stop T8 Ch.2
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch2Stop(void){

	T8_CTL2		= T8_CTL2 & ~(T8_CTL2_PTRUN);
	T8_CLK2		= T8_CLK2 & ~(T8_CLK2_P8TON);

	return;

}


/***************************************************************************
	T8Ch3Stop

	description	: Stop T8 Ch.3
	argument	: None
	return: 	: None
***************************************************************************/
static void T8Ch3Stop(void){

	T8_CTL3		= T8_CTL3 & ~(T8_CTL3_PTRUN);
	T8_CLK3		= T8_CLK3 & ~(T8_CLK3_P8TON);

	return;
}

/***************************************************************************
	T8DummyIntProc

	description	: Interrupt dummy handler
	argument	: None
	return: 	: None
***************************************************************************/
static void T8DummyIntProc(void){
	
	return;
}
